@@ -1,7 +1,11 @@
 from django.apps import AppConfig
 
-from .binding.base import BindingMetaclass
-from .package_checks import check_all
+# We import this here to ensure the reactor is installed very early on
+# in case other packages accidentally import twisted.internet.reactor
+# (e.g. raven does this).
+import daphne.server
+
+assert daphne.server  # pyflakes doesn't support ignores
 
 
 class ChannelsConfig(AppConfig):
@@ -10,10 +14,7 @@ class ChannelsConfig(AppConfig):
     verbose_name = "Channels"
 
     def ready(self):
-        # Check versions
-        check_all()
         # Do django monkeypatches
         from .hacks import monkeypatch_django
+
         monkeypatch_django()
-        # Instantiate bindings
-        BindingMetaclass.register_all()
